==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/is.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Hleð inn forskoðun...",
    "Saved" : "Vistað",
    "Admin" : "Stjórnandi",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Name cannot be empty" : "Heiti má ekki vera tómt",
    "The given name is too long" : "Uppgefið nafn er of langt",
    "The given web address is too long" : "Uppgefið veffang er of langt",
    "The given legal notice address is too long" : "Uppgefið veffang lagatexta er of langt",
    "The given privacy policy address is too long" : "Veffang á stefnu um meðferð persónulegra gagna er of langt",
    "The given slogan is too long" : "Uppgefið slagorð er of langt",
    "The given color is invalid" : "Uppgefinn litur er ógildur",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded" : "Engin skrá var send inn",
    "Unsupported image type" : "Óstudd gerð myndar",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Þú ert nú þegar að nota sérsniðið þema. Mögulega gæti það skrifað yfir stillingar í þemaforriti.",
    "Theming" : "Þemu",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Stefna um meðferð persónulegra gagna",
    "Adjust the Nextcloud theme" : "Laga Nextcloud þema",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Þemu gera þér kleift að breyta útliti og hegðun þíns eintaks af viðmótinu auk studdra biðlaraforrita. Það verður sýnilegt öllum notendum.",
    "Name" : "Heiti",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Web link" : "Veftengill",
    "https://…" : "https://…",
    "Slogan" : "Slagorð",
    "Color" : "Litur",
    "Logo" : "Táknmerki",
    "Upload new logo" : "Senda inn nýtt táknmerki",
    "Login image" : "Innskráningarmynd",
    "Upload new login background" : "Senda inn nýjan bakgrunn innskráningar",
    "Remove background image" : "Fjarlægja bakgrunnsmynd",
    "Advanced options" : "Ítarlegir valkostir",
    "Legal notice link" : "Tengill á lagaleg atriði",
    "Privacy policy link" : "Tengill á stefnu um meðferð persónulegra gagna",
    "Header logo" : "Táknmerki í haus",
    "Upload new header logo" : "Senda inn nýtt táknmerki fyrir síðuhaus",
    "Favicon" : "Veftákn",
    "Upload new favicon" : "Senda inn nýja táknmynd",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Settu inn Imagemagick PHP forritsviðaukann með stuðningi við SVG-myndir til að útbúa sjálfvirkt veftáknmyndir byggðar á innsendu táknmerki og lit.",
    "You are already using a custom theme" : "Þú ert nú þegar að nota sérsniðið þema",
    "reset to default" : "endurstilla á sjálfgefið",
    "Web address" : "Veffang",
    "Web address https://…" : "Veffang https://…",
    "There is no error, the file uploaded with success" : "Engin villa, innsending heppnaðist",
    "The uploaded file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "Failed to write file to disk." : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload." : "PHP-viðbót stöðvaði innsendingu skráar."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/is.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Hleð inn forskoðun...",
    "Saved" : "Vistað",
    "Admin" : "Stjórnandi",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Name cannot be empty" : "Heiti má ekki vera tómt",
    "The given name is too long" : "Uppgefið nafn er of langt",
    "The given web address is too long" : "Uppgefið veffang er of langt",
    "The given legal notice address is too long" : "Uppgefið veffang lagatexta er of langt",
    "The given privacy policy address is too long" : "Veffang á stefnu um meðferð persónulegra gagna er of langt",
    "The given slogan is too long" : "Uppgefið slagorð er of langt",
    "The given color is invalid" : "Uppgefinn litur er ógildur",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded" : "Engin skrá var send inn",
    "Unsupported image type" : "Óstudd gerð myndar",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Þú ert nú þegar að nota sérsniðið þema. Mögulega gæti það skrifað yfir stillingar í þemaforriti.",
    "Theming" : "Þemu",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Stefna um meðferð persónulegra gagna",
    "Adjust the Nextcloud theme" : "Laga Nextcloud þema",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Þemu gera þér kleift að breyta útliti og hegðun þíns eintaks af viðmótinu auk studdra biðlaraforrita. Það verður sýnilegt öllum notendum.",
    "Name" : "Heiti",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Web link" : "Veftengill",
    "https://…" : "https://…",
    "Slogan" : "Slagorð",
    "Color" : "Litur",
    "Logo" : "Táknmerki",
    "Upload new logo" : "Senda inn nýtt táknmerki",
    "Login image" : "Innskráningarmynd",
    "Upload new login background" : "Senda inn nýjan bakgrunn innskráningar",
    "Remove background image" : "Fjarlægja bakgrunnsmynd",
    "Advanced options" : "Ítarlegir valkostir",
    "Legal notice link" : "Tengill á lagaleg atriði",
    "Privacy policy link" : "Tengill á stefnu um meðferð persónulegra gagna",
    "Header logo" : "Táknmerki í haus",
    "Upload new header logo" : "Senda inn nýtt táknmerki fyrir síðuhaus",
    "Favicon" : "Veftákn",
    "Upload new favicon" : "Senda inn nýja táknmynd",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Settu inn Imagemagick PHP forritsviðaukann með stuðningi við SVG-myndir til að útbúa sjálfvirkt veftáknmyndir byggðar á innsendu táknmerki og lit.",
    "There is no error, the file uploaded with success" : "Engin villa, innsending heppnaðist",
    "The uploaded file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "Failed to write file to disk." : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload." : "PHP-viðbót stöðvaði innsendingu skráar.",
    "You are already using a custom theme" : "Þú ert nú þegar að nota sérsniðið þema",
    "Web address https://…" : "Veffang https://…"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
